## CSS - Demos - Tables

<script type="module" src="/web_components/js/css/demos/WebC__CSS__Demo__Tables.mjs"></script>

<webc-container>
    <webc-css-demo-tables        ></webc-css-demo-tables> 
    <webc-css-demo-tables no-css ></webc-css-demo-tables>
    
</webc-container>